@@ -16,7 +16,7 @@ use Config::Std;
 use Data::Dumper qw/Dumper/;
 use SVG::Calendar;
 
-our $VERSION = version->new('0.3.4');
+our $VERSION = version->new('0.3.5');
 
 my %option = (
     moon     => {},
@@ -73,7 +73,7 @@ sub main {
     elsif ( $option{help} ) {
         pod2usage( -verbose => 1 );
     }
-    elsif ( $option{date} ) {
+    elsif ( !$option{date} ) {
         warn "No dates specified, nothing to do!\n";
         pod2usage( -verbose => 1 );
     }
@@ -287,7 +287,7 @@ svgcal.pl - Creates the pages for a calendar in SVG format
 
 =head1 VERSION
 
-This documentation refers to svgcal.pl version 0.3.4.
+This documentation refers to svgcal.pl version 0.3.5.
 
 =head1 SYNOPSIS
 
